@@ -62,7 +62,9 @@ void FlatpakTransactionThread::new_operation_cb(FlatpakTransaction * /*object*/,
 void operation_error_cb(FlatpakTransaction * /*object*/, FlatpakTransactionOperation * /*operation*/, GError *error, gint /*details*/, gpointer user_data)
 {
     FlatpakTransactionThread *obj = (FlatpakTransactionThread *)user_data;
-    obj->addErrorMessage(QString::fromUtf8(error->message));
+    if (error) {
+        obj->addErrorMessage(QString::fromUtf8(error->message));
+    }
 }
 
 gboolean
@@ -122,7 +124,7 @@ FlatpakTransactionThread::~FlatpakTransactionThread()
 
 void FlatpakTransactionThread::cancel()
 {
-    for (int id : m_webflows)
+    for (int id : std::as_const(m_webflows))
         flatpak_transaction_abort_webflow(m_transaction, id);
     g_cancellable_cancel(m_cancellable);
 }
@@ -184,14 +186,20 @@ void FlatpakTransactionThread::run()
     }
 
     m_result = flatpak_transaction_run(m_transaction, m_cancellable, &localError);
-    m_cancelled = g_cancellable_is_cancelled(m_cancellable);
     if (!m_result) {
-        m_errorMessage = QString::fromUtf8(localError->message);
+        if (localError->code == FLATPAK_ERROR_REF_NOT_FOUND) {
+            m_errorMessage = i18n("Could not find '%1' in '%2'; please make sure it's available.", refName, m_app->origin());
+        } else {
+            m_errorMessage = QString::fromUtf8(localError->message);
+        }
 #if defined(FLATPAK_LIST_UNUSED_REFS)
     } else {
         const auto installation = flatpak_transaction_get_installation(m_transaction);
-        g_autoptr(GPtrArray) refs = flatpak_installation_list_unused_refs(installation, nullptr, m_cancellable, nullptr);
-        if (refs->len > 0) {
+        g_autoptr(GError) refsError = nullptr;
+        g_autoptr(GPtrArray) refs = flatpak_installation_list_unused_refs(installation, nullptr, m_cancellable, &refsError);
+        if (!refs) {
+            qWarning() << "could not fetch unused refs" << refsError->message;
+        } else if (refs->len > 0) {
             g_autoptr(GError) localError = nullptr;
             qDebug() << "found unused refs:" << refs->len;
             auto transaction = flatpak_transaction_new_for_installation(installation, m_cancellable, &localError);
@@ -247,3 +255,8 @@ void FlatpakTransactionThread::addErrorMessage(const QString &error)
         m_errorMessage.append(QLatin1Char('\n'));
     m_errorMessage.append(error);
 }
+
+bool FlatpakTransactionThread::cancelled() const
+{
+    return g_cancellable_is_cancelled(m_cancellable);
+}
