@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef RESOURCESMODEL_H
-#define RESOURCESMODEL_H
+#pragma once
 
 #include <QSet>
 #include <QTimer>
@@ -80,6 +79,7 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
     Q_PROPERTY(DiscoverAction *updateAction READ updateAction CONSTANT)
     Q_PROPERTY(int fetchingUpdatesProgress READ fetchingUpdatesProgress NOTIFY fetchingUpdatesProgressChanged)
     Q_PROPERTY(QString applicationSourceName READ applicationSourceName NOTIFY currentApplicationBackendChanged)
+    Q_PROPERTY(InlineMessage *inlineMessage READ inlineMessage NOTIFY inlineMessageChanged)
 public:
     /** This constructor should be only used by unit tests.
      *  @p backendName defines what backend will be loaded when the backend is constructed.
@@ -120,6 +120,12 @@ public:
 
     Q_INVOKABLE QUrl distroBugReportUrl();
 
+    void setInlineMessage(const QSharedPointer<InlineMessage> &inlineMessage);
+    InlineMessage *inlineMessage() const
+    {
+        return m_inlineMessage.data();
+    }
+
 public Q_SLOTS:
     void installApplication(AbstractResource *app, const AddonList &addons);
     void installApplication(AbstractResource *app);
@@ -136,7 +142,7 @@ Q_SIGNALS:
     void passiveMessage(const QString &message);
     void currentApplicationBackendChanged(AbstractResourcesBackend *currentApplicationBackend);
     void fetchingUpdatesProgressChanged(int fetchingUpdatesProgress);
-    void inlineMessage(int type, const QString &iconName, const QString &message);
+    void inlineMessageChanged(const QSharedPointer<InlineMessage> &inlineMessage);
 
 private Q_SLOTS:
     void callerFetchingChanged();
@@ -145,7 +151,7 @@ private Q_SLOTS:
 
 private:
     ///@p initialize tells if all backends load will be triggered on construction
-    explicit ResourcesModel(QObject *parent = nullptr, bool load = true);
+    explicit ResourcesModel(QObject *parent = nullptr);
     void init(bool load);
     void addResourcesBackend(AbstractResourcesBackend *backend);
     void registerBackendByName(const QString &name);
@@ -162,8 +168,7 @@ private:
 
     EmitWhenChanged<int> m_updatesCount;
     EmitWhenChanged<int> m_fetchingUpdatesProgress;
+    QSharedPointer<InlineMessage> m_inlineMessage;
 
     static ResourcesModel *s_self;
 };
-
-#endif // RESOURCESMODEL_H
